summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ChangeLog5
-rw-r--r--generic/tkPanedWindow.c5
2 files changed, 8 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index 8bcae92..f29d830 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,4 +1,9 @@
2003-08-19 Joe English <jenglish@users.sourceforge.net>
+ * generic/tkPanedWindow.c(PanedWindowWorldChanged):
+ Set window background from the -background resource.
+ Fixes [BUG #791500 "PanedWindow refresh glitches on X"]
+
+2003-08-19 Joe English <jenglish@users.sourceforge.net>
* doc/bind.n: Added more information on event types and details
[FRQ #523593 "bind(n) manpage needs more detail"]
diff --git a/generic/tkPanedWindow.c b/generic/tkPanedWindow.c
index 873243c..a95514b 100644
--- a/generic/tkPanedWindow.c
+++ b/generic/tkPanedWindow.c
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkPanedWindow.c,v 1.16 2003/07/18 10:02:03 dkf Exp $
+ * RCS: @(#) $Id: tkPanedWindow.c,v 1.17 2003/08/19 21:00:43 jenglish Exp $
*/
#include "tkPort.h"
@@ -1224,7 +1224,7 @@ PanedWindowWorldChanged(instanceData)
/*
* Allocated a graphics context for drawing the paned window widget
* elements (background, sashes, etc.).
*/
gcValues.background = Tk_3DBorderColor(pwPtr->background)->pixel;
@@ -1233,6 +1233,7 @@ PanedWindowWorldChanged(instanceData)
Tk_FreeGC(pwPtr->display, pwPtr->gc);
}
pwPtr->gc = newGC;
+ Tk_SetWindowBackground(pwPtr->tkwin, gcValues.background);
/*
* Issue geometry size requests to Tk.
@@ -1224,7 +1224,7 @@ PanedWindowWorldChanged(instanceData)
/*
* Allocated a graphics context for drawing the paned window widget
- * elements (background, sashes, etc.).
+ * elements (background, sashes, etc.) and set the window background.
*/
gcValues.background = Tk_3DBorderColor(pwPtr->background)->pixel;